@@ -1,9 +1,9 @@
 /*
- * Copyright 2005-2012 Gentoo Foundation
+ * Copyright 2005-2024 Gentoo Foundation
  * Distributed under the terms of the GNU General Public License v2
  *
  * Copyright 2005-2012 Ned Ludd        - <solar@gentoo.org>
- * Copyright 2005-2012 Mike Frysinger  - <vapier@gentoo.org>
+ * Copyright 2005-2024 Mike Frysinger  - <vapier@gentoo.org>
  *
  * Make sure all of the common elf stuff is setup as we expect
  */
@@ -12,11 +12,17 @@
 #define _PAX_ELF_H
 
 typedef struct {
-	void *phdr;
-	void *shdr;
+	const void *phdr;
+	const void *shdr;
+	/* When we need to duplicate the ELF buffer for alignment. */
 	void *_data;
-	union { void *ehdr, *vdata; char *data; uintptr_t udata; };
-	void *data_end;
+	union {
+		const void *ehdr, *vdata;
+		const char *cdata;
+		const unsigned char *data;
+		uintptr_t udata;
+	};
+	const void *data_end;
 	char elf_class;
 	off_t len;
 	int fd;
@@ -53,18 +59,18 @@ typedef struct {
 extern const char *pax_short_hf_flags(unsigned long flags);
 extern const char *pax_short_pf_flags(unsigned long flags);
 extern const char *gnu_short_stack_flags(unsigned long flags);
-extern elfobj *readelf_buffer(const char *filename, void *buffer, size_t buffer_len);
+extern elfobj *readelf_buffer(const char *filename, const void *buffer, size_t buffer_len);
 extern elfobj *_readelf_fd(const char *filename, int fd, size_t len, int read_only);
 #define readelf_fd(filename, fd, len) _readelf_fd(filename, fd, len, 1)
 extern elfobj *_readelf(const char *filename, int read_only);
 #define readelf(filename) _readelf(filename, 1)
 extern void unreadelf(elfobj *elf);
 extern const char *get_elfeitype(int ei_type, int type);
-extern const char *get_elfetype(elfobj *elf);
-extern const char *get_endian(elfobj *elf);
-extern const char *get_elfosabi(elfobj *elf);
-extern const char *get_elf_eabi(elfobj *elf);
-extern const char *get_elfemtype(elfobj *elf);
+extern const char *get_elfetype(const elfobj *elf);
+extern const char *get_endian(const elfobj *elf);
+extern const char *get_elfosabi(const elfobj *elf);
+extern const char *get_elf_eabi(const elfobj *elf);
+extern const char *get_elfemtype(const elfobj *elf);
 extern const char *get_elfptype(int type);
 extern const char *get_elfdtype(int type);
 extern const char *get_elfshntype(int type);
@@ -73,9 +79,9 @@ extern const char *get_elfstbtype(int type);
 extern const char *get_elfstvtype(int type);
 extern const char *get_elfstttype(int type);
 extern const char *get_elfnttype(uint16_t e_type, const char *name, int type);
-extern void *elf_findsecbyname(elfobj *elf, const char *name);
-extern unsigned int get_etype(elfobj *elf);
-extern unsigned int get_emtype(elfobj *elf);
+extern const void *elf_findsecbyname(const elfobj *elf, const char *name);
+extern unsigned int get_etype(const elfobj *elf);
+extern unsigned int get_emtype(const elfobj *elf);
 extern void print_etypes(FILE *);
 extern unsigned int etype_lookup(const char *);
 
