@@ -1,9 +1,9 @@
 /*
- * Copyright 2003-2016 Gentoo Foundation
+ * Copyright 2003-2024 Gentoo Foundation
  * Distributed under the terms of the GNU General Public License v2
  *
  * Copyright 2003-2012 Ned Ludd        - <solar@gentoo.org>
- * Copyright 2004-2016 Mike Frysinger  - <vapier@gentoo.org>
+ * Copyright 2004-2024 Mike Frysinger  - <vapier@gentoo.org>
  */
 
 #ifndef _PAX_LDSO_H
@@ -26,7 +26,7 @@
 #if PAX_LDSO_CACHE
 extern char *ldso_cache_lookup_lib(elfobj *elf, const char *fname);
 #else
-static inline char *ldso_cache_lookup_lib(elfobj *elf, const char *fname)
+static inline char *ldso_cache_lookup_lib(__unused__ elfobj *elf, __unused__ const char *fname)
 {
 	return NULL;
 }
@@ -49,11 +49,12 @@ static inline char *ldso_cache_lookup_lib(elfobj *elf, const char *fname)
 # define PAX_LDSO_CONFIG 1
 #endif
 
-#if PAX_LDSO_CONFIG
+/* Consumers refer to ldpaths directly, so can't hide its def. */
 extern array_t *ldpaths;
+#if PAX_LDSO_CONFIG
 extern int ldso_config_load(const char *fname);
 #else
-static inline int ldso_config_load(const char *fname)
+static inline int ldso_config_load(__unused__ const char *fname)
 {
 	return 0;
 }
@@ -65,4 +66,7 @@ extern void paxldso_cleanup(void);
 # define paxldso_cleanup()
 #endif
 
+/* Path to ld.so.cache. Usually overridden for tests. */
+extern const char *ldcache_path;
+
 #endif
