@@ -1,15 +1,16 @@
 /*
  * Generate the bpf rules ahead of time to speed up runtime.
  *
- * Copyright 2015 Gentoo Foundation
+ * Copyright 2015-2024 Gentoo Foundation
  * Distributed under the terms of the GNU General Public License v2
  *
- * Copyright 2015 Mike Frysinger  - <vapier@gentoo.org>
+ * Copyright 2015-2024 Mike Frysinger  - <vapier@gentoo.org>
  */
 
 const char argv0[] = "seccomp-bpf";
 
 #include <err.h>
+#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -49,7 +50,7 @@ static const struct {
 };
 
 /* Simple helper to add all of the syscalls in an array. */
-static int gen_seccomp_rules_add(scmp_filter_ctx ctx, int syscalls[], size_t num)
+static int gen_seccomp_rules_add(scmp_filter_ctx ctx, const int syscalls[], size_t num, uint32_t action)
 {
 	static uint8_t prio;
 	size_t i;
@@ -58,14 +59,14 @@ static int gen_seccomp_rules_add(scmp_filter_ctx ctx, int syscalls[], size_t num
 			warn("seccomp_syscall_priority failed");
 			return -1;
 		}
-		if (seccomp_rule_add(ctx, SCMP_ACT_ALLOW, syscalls[i], 0) < 0) {
+		if (seccomp_rule_add(ctx, action, syscalls[i], 0) < 0) {
 			warn("seccomp_rule_add failed");
 			return -1;
 		}
 	}
 	return 0;
 }
-#define gen_seccomp_rules_add(ctx, syscalls) gen_seccomp_rules_add(ctx, syscalls, ARRAY_SIZE(syscalls))
+#define gen_seccomp_rules_add(ctx, syscalls, action) gen_seccomp_rules_add(ctx, syscalls, ARRAY_SIZE(syscalls), action)
 
 static void gen_seccomp_dump(scmp_filter_ctx ctx, const char *name)
 {
@@ -102,7 +103,7 @@ static void gen_seccomp_program(const char *name)
 int main(void)
 {
 	/* Order determines priority (first == lowest prio).  */
-	int base_syscalls[] = {
+	static const int base_syscalls[] = {
 		/* We write the most w/scanelf.  */
 		SCMP_SYS(write),
 		SCMP_SYS(writev),
@@ -130,6 +131,7 @@ int main(void)
 		/* Then the memory mapping functions.  */
 		SCMP_SYS(mmap),
 		SCMP_SYS(mmap2),
+		SCMP_SYS(mremap),
 		SCMP_SYS(munmap),
 
 		/* Then the directory reading functions.  */
@@ -190,8 +192,14 @@ int main(void)
 		 * as ipc() subcalls.  #675378
 		 */
 		SCMP_SYS(ipc),
+
+		/* glibc-2.34+ uses it as part of mem alloc functions. */
+		SCMP_SYS(getrandom),
+
+		/* glibc-2.35+ uses it when GLIBC_TUNABLES=glibc.malloc.hugetlb=1. */
+		SCMP_SYS(madvise),
 	};
-	int fork_syscalls[] = {
+	static const int fork_syscalls[] = {
 		SCMP_SYS(clone),
 		SCMP_SYS(execve),
 		SCMP_SYS(fork),
@@ -203,6 +211,9 @@ int main(void)
 		SCMP_SYS(waitid),
 		SCMP_SYS(waitpid),
 	};
+	static const int soft_error_syscalls[] = {
+		SCMP_SYS(socket),
+	};
 
 	/* TODO: Handle debug and KILL vs TRAP. */
 
@@ -235,11 +246,13 @@ int main(void)
 		printf("/* %s */\n", gen_seccomp_arches[i].name);
 		printf("#define SECCOMP_BPF_AVAILABLE\n");
 
-		if (gen_seccomp_rules_add(ctx, base_syscalls) < 0)
+		if (gen_seccomp_rules_add(ctx, base_syscalls, SCMP_ACT_ALLOW) < 0)
+			err(1, "seccomp_rules_add failed");
+		if (gen_seccomp_rules_add(ctx, soft_error_syscalls, SCMP_ACT_ERRNO(ENOSYS)) < 0)
 			err(1, "seccomp_rules_add failed");
 		gen_seccomp_dump(ctx, "base");
 
-		if (gen_seccomp_rules_add(ctx, fork_syscalls) < 0)
+		if (gen_seccomp_rules_add(ctx, fork_syscalls, SCMP_ACT_ALLOW) < 0)
 			err(1, "seccomp_rules_add failed");
 		gen_seccomp_dump(ctx, "fork");
 
